@@ -30,34 +30,10 @@
 
 @implementation DictConnection
 
-
-/**
- * Initialises the DictionaryHandle from the property list aPropertyList.
- */
--(id) initFromPropertyList: (NSDictionary*) aPropertyList
-{
-    NSAssert1([aPropertyList objectForKey: @"host"] != nil,
-              @"No entry for 'host' key in NSDictionary %@", aPropertyList);
-    NSAssert1([aPropertyList objectForKey: @"port"] != nil,
-              @"No entry for 'host' key in NSDictionary %@", aPropertyList);
-    
-    if ((self = [super initFromPropertyList: aPropertyList]) != nil) {
-        self = [self initWithHost: [aPropertyList objectForKey: @"host"]
-                             port: [[aPropertyList objectForKey: @"port"] intValue]];
-    }
-    
-    return self;
-}
-
 -(id)initWithHost: (NSHost*) aHost
 	     port: (int) aPort
 {
   if (self = [super init]) {
-    if (aHost == nil) {
-        [self release];
-        return nil;
-    }
-    
     ASSIGN(host, aHost);
     port = aPort;
     
@@ -114,12 +90,12 @@
   
   NSString* answer = [reader readLineAndRetry];
   
-  if (![answer hasPrefix: @"250"]) {
+  if (![answer startsWith: @"250"]) {
     LOG(@"Answer not accepted?: %@", answer);
   }
 }
 
--(void) handleDescription
+-(void) serverDescription
 {
   [self showError: @"Retrieval of server descriptions not implemented yet."];
 }
@@ -130,7 +106,7 @@
 }
 
 -(void) definitionFor: (NSString*) aWord
-         inDictionary: (NSString*) aDict
+	 inDictionary: (NSString*) aDict
 {
   NSMutableString* result = [NSMutableString stringWithCapacity: 100];
   
@@ -141,17 +117,18 @@
   
   NSString* answer = [reader readLineAndRetry];
   
-  if ([answer hasPrefix: @"552"]) { // word not found
-    [defWriter writeHeadline:
-		 [NSString stringWithFormat: @"No results from %@", self]];
-  } else if ([answer hasPrefix: @"550"]) {
+  if ([answer startsWith: @"552"]) { // word not found
+    [defWriter clearResults];
+    [defWriter writeHeadline: @"No results"];
+  } else if ([answer startsWith: @"550"]) {
     [self
       showError: [NSString stringWithFormat: @"Invalid database: %@", aDict]];
-  } else if ([answer hasPrefix: @"150"]) { // got results
+  } else if ([answer startsWith: @"150"]) { // got results
+    [defWriter clearResults];
     BOOL lastDefinition = NO;
     do {
       answer = [reader readLineAndRetry];
-      if ([answer hasPrefix: @"151"]) {
+      if ([answer startsWith: @"151"]) {
 	[defWriter writeHeadline:
 		     [NSString stringWithFormat: @"From %@:",
 			       [answer dictLineComponent: 3]]
@@ -171,7 +148,7 @@
 	} while (lastLine == NO);
       } else {
 	lastDefinition = YES;
-	if (![answer hasPrefix: @"250"]) {
+	if (![answer startsWith: @"250"]) {
 	  [self showError: answer];
 	}
       }
@@ -213,14 +190,14 @@
   
   
   // interprete server banner
-  if ([banner hasPrefix: @"220"]) {
+  if ([banner startsWith: @"220"]) {
     LOG(@"Server banner: %@", banner);
   } else {
-    if ([banner hasPrefix: @"530"]) {
+    if ([banner startsWith: @"530"]) {
       [self showError: @"Access to server denied."];
-    } else if ([banner hasPrefix: @"420"]) {
+    } else if ([banner startsWith: @"420"]) {
       [self showError: @"Temporarily unavailable."];
-    } else if ([banner hasPrefix: @"421"]) {
+    } else if ([banner startsWith: @"421"]) {
       [self showError: @"Server shutting down at operator request."];
     } else {
       LOG(@"Bad banner: %@", banner);
@@ -247,7 +224,8 @@
 
 -(void) showError: (NSString*) aString
 {
-  [defWriter writeBigHeadline: [NSString stringWithFormat: @"%@ Error", self]];
+  [defWriter clearResults];
+  [defWriter writeBigHeadline: @"Error"];
   [defWriter writeLine: aString];
 }
 
@@ -256,20 +234,5 @@
   ASSIGN(defWriter, aDefinitionWriter);
 }
 
--(NSDictionary*) shortPropertyList
-{
-    NSMutableDictionary* result = [super shortPropertyList];
-    
-    [result setObject: host forKey: @"host"];
-    [result setObject: [NSNumber numberWithBool: port] forKey: @"port"];
-    
-    return result;
-}
-
--(NSString*) description
-{
-  return [NSString stringWithFormat: @"Dictionary at %@", host];
-}
-
 @end
 
